==> aws-android-sdk-cognito-2.7.3-sources.jar: com/amazonaws/services/cognitosync/model/transform/UpdateRecordsResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitosync.model.transform;

import com.amazonaws.services.cognitosync.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response UpdateRecordsResult
 */
public class UpdateRecordsResultJsonUnmarshaller implements
        Unmarshaller<UpdateRecordsResult, JsonUnmarshallerContext> {

    public UpdateRecordsResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        UpdateRecordsResult updateRecordsResult = new UpdateRecordsResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("Records")) {
                updateRecordsResult.setRecords(new ListUnmarshaller<Record>(RecordJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return updateRecordsResult;
    }

    private static UpdateRecordsResultJsonUnmarshaller instance;

    public static UpdateRecordsResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new UpdateRecordsResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognito-2.8.5-sources.jar: com/amazonaws/services/cognitosync/model/transform/UpdateRecordsResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitosync.model.transform;

import com.amazonaws.services.cognitosync.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response UpdateRecordsResult
 */
public class UpdateRecordsResultJsonUnmarshaller implements
        Unmarshaller<UpdateRecordsResult, JsonUnmarshallerContext> {

    public UpdateRecordsResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        UpdateRecordsResult updateRecordsResult = new UpdateRecordsResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("Records")) {
                updateRecordsResult.setRecords(new ListUnmarshaller<Record>(RecordJsonUnmarshaller
                        .getInstance()).unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return updateRecordsResult;
    }

    private static UpdateRecordsResultJsonUnmarshaller instance;

    public static UpdateRecordsResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new UpdateRecordsResultJsonUnmarshaller();
        return instance;
    }
}
